@@ -27,6 +27,9 @@
 --
 --
 -- $Log: check_block_maps.c,v $
+-- Revision 1.19  2008/04/02 03:06:21  jsedwards
+-- Added file locking.
+--
 -- Revision 1.18  2008/02/03 01:15:40  jsedwards
 -- Change to use nwos_get_private_objects_path function instead of DEFAULT_FILE.
 --
@@ -119,6 +122,7 @@
 */
 
 
+#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -157,6 +161,7 @@ bool reference_matches(uint32 ref, uint8 *block)
 int main(int argc, char* argv[])
 {
     int obj_file_desc;
+    struct flock lock;
     const char * obj_file_path;
     char ref_str[128];
     uint8 *chunk;
@@ -195,6 +200,18 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
+    lock.l_type = F_RDLCK;
+    lock.l_whence = SEEK_SET;
+    lock.l_start = 0;
+    lock.l_len = 0;
+
+    if (fcntl(obj_file_desc, F_SETLK, &lock) != 0)
+    {
+	perror(obj_file_path);
+	exit(1);
+    }
+
+
     /* allocate buffer for reading chunks */
 
     chunk = malloc(CHUNK_SIZE);
