@@ -27,6 +27,17 @@
 --
 --
 -- $Log: dump_obj.c,v $
+-- Revision 1.17  2008/08/02 11:02:24  jsedwards
+-- Added call to log arguments to disable logging and fixed typo in print
+-- statement text.
+--
+-- Revision 1.16  2008/08/01 14:36:54  jsedwards
+-- Added code to print class name and to dump object data in hex.
+--
+-- Revision 1.15  2008/08/01 00:35:04  jsedwards
+-- Changed to try old decryption algorithm if checksum fails after reading
+-- with new decryption algorithm.
+--
 -- Revision 1.14  2008/07/19 14:19:29  jsedwards
 -- Removed some unused variables.
 --
@@ -124,6 +135,14 @@ int main(int argc, char* argv[])
     int seq = 0;
     Extra_Data_Block extra;
     EveryObject* header;
+    uint8 chksum[4];
+    C_struct_Class_Definition class_def_obj;
+    char class_name[64];
+    size_t size;
+    uint8 *data;
+    int i;
+
+    nwos_log_arguments(0, NULL);   /* disable logging */
 
     printf("\n");
 
@@ -185,6 +204,28 @@ int main(int argc, char* argv[])
 
     header = (EveryObject*) &extra;
 
+    nwos_crc32_calculate((uint8*)&header->object, sizeof(header->object), chksum);
+
+    if (memcmp(&header->common.header_chksum, chksum, 4) != 0)
+    {
+	fprintf(stderr, "Warning: checksum with new decryption algorithm failed, trying old algorithm...\n");
+
+	memset(ivec, 0, sizeof(ivec));
+
+	if (!nwos_read_object_from_disk_and_old_decrypt(&ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]))
+	{
+	    fprintf(stderr, "Error: nwos_read_object_from_disk_and_old_decrypt failed\n");
+	    exit(1);
+	}
+
+	nwos_crc32_calculate((uint8*)&header->object, sizeof(header->object), chksum);
+
+	if (memcmp(&header->common.header_chksum, chksum, 4) != 0)
+	{
+	    fprintf(stderr, "Error: checksum with old decryption algorithm failed as well.\n");
+	}
+    }
+
     printf("Creation: %s\n", nwos_time_stamp_to_string(header->common.creation_time));
 
     printf("Checksums:\n");
@@ -193,7 +234,10 @@ int main(int argc, char* argv[])
     printf("    Data: %02x%02x%02x%02x\n", header->common.data_chksum[0], header->common.data_chksum[1],
 	   header->common.data_chksum[2], header->common.data_chksum[3]);
 
-    printf("Class: %08x\n", nwos_ref_to_word(&header->common.class_definition));
+    nwos_read_class_definition(&header->common.class_definition, &class_def_obj);
+    nwos_name_to_string(&class_def_obj.name, class_name, sizeof(class_name));
+
+    printf("Class: %08x - %s\n", nwos_ref_to_word(&header->common.class_definition), class_name);
 
     printf("Clone Of: %08x\n", nwos_ref_to_word(&header->object.clone_of));
     printf("References: %08x\n", nwos_ref_to_word(&header->object.references));
@@ -203,15 +247,37 @@ int main(int argc, char* argv[])
     printf("Prev_version: %08x\n", nwos_ref_to_word(&header->object.prev_version));
     printf("Next_version: %08x\n", nwos_ref_to_word(&header->object.next_version));
 
-#if 0
-    nwos_read_object_from_disk(&ref, &class_def_obj, sizeof(class_def_obj));
+    size = nwos_get_object_size(&extra);
 
-    nwos_name_to_string(&class_def_obj.name, class_name, sizeof(class_name));
+    data = malloc(size);
 
-    printf(" - %s\n", class_name);
-#endif
+    if (data == NULL)
+    {
+	perror("allocating space for object");
+	exit(1);
+    }
 
-    //size_t nwos_get_object_size(void* object)
+    nwos_read_object_from_disk(&ref, data, size);
+
+    printf("\n");
+
+    for (i = sizeof(EveryObject); i < size; i++)
+    {
+	printf("%02x", data[i]);
+
+	if (i % 16 == 3 || i % 16 == 7 || i % 16 == 11)
+	{
+	    printf("  ");
+	}
+	else if (i % 16 == 15)
+	{
+	    printf("\n");
+	}
+	else
+	{
+	    printf(" ");
+	}
+    }
 
     printf("\n");
 
