@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2007  QRW Software
+--                 Copyright (C) 2005-2008  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,9 @@
 --
 --
 -- $Log: name.c,v $
+-- Revision 1.34  2008/04/26 11:42:18  jsedwards
+-- Added 'const' to char* name parameter in some of the functions.
+--
 -- Revision 1.33  2007/07/01 19:44:12  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -211,11 +214,11 @@ static ObjRef* get_private_name_class_ref()
 }
 
 
-static int split_name(char* name, char words[21][20])
+static int split_name(const char* name, char words[21][20])
 {
     int result = 0; 
     int i;
-    char* p;
+    const char* p;
 
     i = 0;
     for (p = name; *p != '\0'; p++)
@@ -253,7 +256,7 @@ static size_t get_name_object_size(void* name_obj)
 }
 
 
-bool nwos_find_public_name(char* name, ObjRef* ref)
+bool nwos_find_public_name(const char* name, ObjRef* ref)
 {
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
@@ -458,7 +461,7 @@ bool nwos_find_public_name(char* name, ObjRef* ref)
 }
 
 
-bool nwos_find_private_name(char* name, ObjRef* ref)
+bool nwos_find_private_name(const char* name, ObjRef* ref)
 {
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
@@ -668,7 +671,7 @@ bool nwos_find_private_name(char* name, ObjRef* ref)
 /* NOTE: the find part could be extracted from the create name below, but */
 /* I'm not sure exactly how to do it right now so I am leaving it as is.  */
 
-ObjCreateResult nwos_create_name(char* name, ObjRef* ref)
+ObjCreateResult nwos_create_name(const char* name, ObjRef* ref)
 {
     uint8 kludge[FILE_BLOCK_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
