@@ -27,6 +27,9 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.69  2008/07/31 14:01:56  jsedwards
+-- Added external declaration for nwos_read_object_from_disk_and_old_decrypt.
+--
 -- Revision 1.68  2008/07/19 13:33:16  jsedwards
 -- Added external declarations for new disk_io_is_read_only and
 -- disk_io_is_read_write functions in disk_io.c file.
@@ -486,6 +489,7 @@ extern void nwos_create_public_acronym(char* acronym, ObjRef* ref);
 extern uint32 nwos_next_sequence(uint32* linear_seed, uint32* serial_seed);
 
 extern bool nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
+extern bool nwos_read_object_from_disk_and_old_decrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 extern void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t size, uint8 ivec[IVEC_SIZE], uint8 seq_table[FILE_BLOCK_SIZE]);
 
 extern const char* nwos_public_path;
